pub struct Topic {
pub id: String,
pub created_at: String,
pub updated_at: String,
pub name: String,
pub email_total: usize,
pub sms_total: usize,
pub push_total: usize,
pub subscribe: Vec<Value>,
}Expand description
Topic
Fields
id: StringTopic ID.
created_at: StringMessage creation time in ISO 8601 format.
updated_at: StringMessage update date in ISO 8601 format.
name: StringThe name of the topic.
email_total: usizeTotal count of email subscribers subscribed to the topic.
sms_total: usizeTotal count of SMS subscribers subscribed to the topic.
push_total: usizeTotal count of push subscribers subscribed to the topic.
subscribe: Vec<Value>Subscribe permissions.